fedex

Package fedex |
[hide private]
[frames] | no frames]

# Source Code for Package fedex

     1  """
     2  python-fedex API Documentation
     3  ==============================
     4  The python-fedex module is a light wrapper around Fedex's Web Services SOAP API.
     5  Using the excellent U{suds<https://fedorahosted.org/suds/>} SOAP client,
     6  the Fedex requests and responses are trivial to work with.
     7
     8  What python-fedex is
     9  --------------------
    10      - A light wrapper around Fedex Web Services SOAP API.
    11      - Simple and easy to use.
    12      - Minimal by design.
    13
    14  What python-fedex is not
    15  ------------------------
    16      - An abstraction layer. python-fedex only assembles the needed SOAP calls
    17          and returns a SOAP response through suds. This is easy enough to work with
    18          that no abstraction is needed. Doing so would limit your use of the data.
    19      - Anything more than a light wrapper.
    20
    21  A note on completeness
    22  ----------------------
    23  python-fedex was created for use with some of my internal projects. For the
    24  initial release, only the things that I needed at the time were implemented.
    25  If there is missing functionality, please report an U{issue<http://code.google.com/p/python-fedex/issues/list>}
    26  so that I may make this module more useful to others. Likewise, feel free to
    27  submit patches as well if you would like to help.
    28
    29  Getting Started
    30  ---------------
    31  The best place to get started is by viewing the examples in the 'examples'
    32  directory. These should be very self-explanatory. For further details, you
    33  may review the API here, or get support by reading the instructions in the
    34  appropriately named section below.
    35
    36  The L{services} module is also a good place to start looking at the different
    37  objects used for issuing Fedex requests.
    38
    39  As a general tip, the best way to see which attributes are available on WSDL
    40  objects is to simply print them, hitting their __str__() method.
    41
    42  Fedex Documentation
    43  -------------------
    44  If you are wondering what attributes or variables are present, you'll want to
    45  refer to the Fedex Web Services documentation at http://fedex.com/developer/.
    46  Complete specification documents are there, which correspond very closely with
    47  what you'll be able to do with python-fedex.
    48
    49  Getting Support
    50  ---------------
    51  If you have any questions, problems, ideas, or patch submissions, please visit
    52  our U{Google Code project<http://code.google.com/p/python-fedex/>} and enter
    53  an issue in the U{Issue Tracker<http://code.google.com/p/python-fedex/issues/list>}.
    54  """
    55  VERSION = '1.0.4'
    56